@@ -7,6 +7,8 @@
 
 #include <glib.h>
 
+G_BEGIN_DECLS
+
 #define             GCR_DATA_ERROR                    (gcr_data_error_get_domain ())
 
 GQuark 	            gcr_data_error_get_domain         (void) G_GNUC_CONST;
@@ -45,9 +47,11 @@ enum {
 	GCR_FORMAT_PEM_PKCS12
 };
 
-/* Forward declare some of the GP11 objects */
-struct _GP11Attributes;
-struct _GP11Object;
-struct _GP11Slot;
+/* Forward declare some of the Gck objects */
+struct _GckAttributes;
+struct _GckObject;
+struct _GckSlot;
+
+G_END_DECLS
 
 #endif /* GCRTYPES_H_ */
